aboutsummaryrefslogtreecommitdiffstats
path: root/app/base_app.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'app/base_app.hpp')
-rw-r--r--app/base_app.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/app/base_app.hpp b/app/base_app.hpp
index 1f0c319..94b12cc 100644
--- a/app/base_app.hpp
+++ b/app/base_app.hpp
@@ -22,11 +22,11 @@ class BaseApp {
// where app_attribues is an instance of AppAttributes
virtual AppReturnValues render(Api *app_api) = 0; // Has to be implemented
- // Called when a button is released.
- // \param delta The time since the button has been last released. Delta is in ms, from time_since_button_press().
- virtual AppReturnValues btnpressed(Api *app_api, uint gpio, unsigned long delta) {return AppReturnValues::OK;};
+ // Called when a button is pressed.
+ // \param delta The time since the button been last released. Delta is in ms, from time_since_button_press().
+ virtual AppReturnValues btn_pressed(Api *app_api, uint gpio, unsigned long delta) {return AppReturnValues::OK;};
// Called when a button is released.
// \param delta The time since the button has been pressed. Delta is in ms, from time_since_button_press().
- virtual AppReturnValues btnreleased(Api *app_api, uint gpio, unsigned long delta) {return AppReturnValues::OK;};
+ virtual AppReturnValues btn_released(Api *app_api, uint gpio, unsigned long delta) {return AppReturnValues::OK;};
virtual AppReturnValues bgrefresh(Api *app_api, bool in_foreground) {return AppReturnValues::OK;};
};